@@ -83,7 +83,7 @@
 }
 
 .get.series <- function(this, index) {
-  F <- numeric(this$length);
+  F <- numeric(prod(this$length));
   for (i in index) {
     name <- paste("series:", i, sep = "");
     F <- F + .get(this, name);
@@ -112,6 +112,8 @@ clusterify <- function(this, ...)
   UseMethod("clusterify");
 calc.v <- function(this, ...)
   UseMethod("calc.v");
+rforecast <- function(this, ...)
+  UseMethod("rforecast")
 
 .object.size <- function(this, ...)
   UseMethod(".object.size")
